==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/python/Venv.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Manages a virtual environment through the Python venv module.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.911Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.Venv")
public class Venv extends io.github.cdklabs.projen.Component implements io.github.cdklabs.projen.python.IPythonEnv {

    protected Venv(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Venv(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Venv(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.python.PythonProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.python.VenvOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Venv(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.python.PythonProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Initializes the virtual environment if it doesn't exist (called during post-synthesis).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void setupEnvironment() {
        software.amazon.jsii.Kernel.call(this, "setupEnvironment", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.python.Venv}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.python.Venv> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.python.PythonProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.python.PythonProject project;
        private io.github.cdklabs.projen.python.VenvOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.python.PythonProject project) {
            this.project = project;
        }

        /**
         * (experimental) Name of directory to store the environment in.
         * <p>
         * Default: ".env"
         * <p>
         * @return {@code this}
         * @param envdir Name of directory to store the environment in. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder envdir(final java.lang.String envdir) {
            this.options().envdir(envdir);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.python.Venv}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.python.Venv build() {
            return new io.github.cdklabs.projen.python.Venv(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.python.VenvOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.python.VenvOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/python/Venv.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Manages a virtual environment through the Python venv module.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.578Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.Venv")
public class Venv extends io.github.cdklabs.projen.Component implements io.github.cdklabs.projen.python.IPythonEnv {

    protected Venv(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Venv(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Venv(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.python.VenvOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Venv(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Initializes the virtual environment if it doesn't exist (called during post-synthesis).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void setupEnvironment() {
        software.amazon.jsii.Kernel.call(this, "setupEnvironment", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.python.Venv}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.python.Venv> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private io.github.cdklabs.projen.python.VenvOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
        }

        /**
         * (experimental) Name of directory to store the environment in.
         * <p>
         * Default: ".env"
         * <p>
         * @return {@code this}
         * @param envdir Name of directory to store the environment in. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder envdir(final java.lang.String envdir) {
            this.options().envdir(envdir);
            return this;
        }

        /**
         * (experimental) Path to the python executable to use.
         * <p>
         * Default: "python"
         * <p>
         * @return {@code this}
         * @param pythonExec Path to the python executable to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pythonExec(final java.lang.String pythonExec) {
            this.options().pythonExec(pythonExec);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.python.Venv}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.python.Venv build() {
            return new io.github.cdklabs.projen.python.Venv(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.python.VenvOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.python.VenvOptions.Builder();
            }
            return this.options;
        }
    }
}
